# 
# This file is part of Dist-Zilla-Plugin-Twitter
# 
# This software is Copyright (c) 2010 by David Golden.
# 
# This is free software, licensed under:
# 
#   The Apache License, Version 2.0, January 2004
# 
use strict;
use warnings;
package DZ1;
# ABSTRACT: this is a sample package for testing Dist::Zilla;

sub main {
  return 1;
}

1;
